==> hexalate_1.1.2.orig.tar.gz: hexalate-1.1.2/translations/hexalate_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Abort current game?</source>
        <translation>Huidig spel afbreken?</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selekteer Taal:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systeem Taal&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Aantekening</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Herstart AUB dit programma om de verandering van de taal door te voeren.</translation>
    </message>
</context>
<context>
    <name>Puzzle</name>
    <message>
        <source>Success</source>
        <translation>Succes</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Unable to load previous game. Starting a new game.</source>
        <translation>Kan huidige spel onmogelijk laden. Begin een nieuw spel.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Hexalate</source>
        <translation>Hexalate</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spel</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Einde</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Instellingen</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programma &amp;Taal...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <source>About Hexalate</source>
        <translation>Over Hexalate</translation>
    </message>
    <message>
        <source>A color matching game</source>
        <translation>Een kleuren combinatiespel</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Auteursrecht &amp;copie; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Uitgebracht omder de &lt;a href=%1&gt;GPL 3&lt;/a&gt; licensie</translation>
    </message>
</context>
</TS>

==> hexalate_1.2.0.orig.tar.gz: hexalate-1.2.0/translations/hexalate_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Abort current game?</source>
        <translation>Huidig spel afbreken?</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Taal selecteren:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Opmerking</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Herstart de applicatie om de taalwijziging toe te passen.</translation>
    </message>
</context>
<context>
    <name>Puzzle</name>
    <message>
        <source>Success</source>
        <translation>Voltooid</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Unable to load previous game. Starting a new game.</source>
        <translation>Het vorige spel kan niet worden geladen; start een nieuw spel.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Hexalate</source>
        <translation>Hexalate</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spel</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>In&amp;stellingen</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Applicatietaa&amp;l...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <source>About Hexalate</source>
        <translation>Over Hexalate</translation>
    </message>
    <message>
        <source>A color matching game</source>
        <translation>Een kleurenkoppelspel</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Auteursrecht &amp;copie; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Uitgebracht onder de &lt;a href=%1&gt;GPL 3&lt;/a&gt;-licentie</translation>
    </message>
</context>
</TS>
